import {
    Sheet,
    SheetContent,
    SheetTrigger,
} from '@/components/ui/sheet';
import { Button } from '@/components/ui/button';
import { useEffect, useState } from 'react';
import { motion, AnimatePresence } from 'framer-motion';
import {
    X,
    Bell,
    MessageSquare,
    Globe,
    Repeat,
    BarChart2,
    Settings,
    User,
    Share2,
    HelpCircle,
    LogOut,
    Replace,
} from 'lucide-react';
import { useNavigate } from 'react-router-dom';
import { supabase } from '@/lib/supabase';
import { useUser } from '@/hooks/use-user';
import { toast } from '@/components/ui/use-toast'; // ✅ ensure this import
import NotificationPanel from '@/components/NotificationPanel';

export default function AirbnbStyleMenu() {
    const [open, setOpen] = useState(false);
    const [showNotifications, setShowNotifications] = useState(false);
    const navigate = useNavigate();
    const { user } = useUser();

    const [profile, setProfile] = useState({
        fullName: '',
        role: '',
        avatarLetter: '',
        avatarUrl: '',
    });
    const [loading, setLoading] = useState(true);

    // ✅ Fix: Move SwitchMode as a usable function
    const switchMode = async () => {
        if (!user) return;
        const currentRole = user.role;
        const newRole = currentRole === 'host' ? 'guest' : 'host';

        const { error: authError } = await supabase.auth.updateUser({
            data: { role: newRole },
        });

        if (authError) {
            toast({ title: 'Error', description: 'Failed to update user role.' });
            return;
        }

        const { error: dbError } = await supabase
            .from('users')
            .update({ role: newRole })
            .eq('id', user.id);

        if (dbError) {
            toast({ title: 'Error', description: 'Failed to update database role.' });
            return;
        }

        navigate('/');

        window.location.reload();
    };

    useEffect(() => {
        const fetchData = async () => {
            if (!user?.id) return;
            const { data: userData } = await supabase
                .from('users')
                .select('full_name, role')
                .eq('id', user.id)
                .single();

            const { data: userProfile } = await supabase
                .from('user_profile')
                .select('avatar_url')
                .eq('user_id', user.id)
                .single();

            setProfile({
                fullName: userData?.full_name || '',
                role: userData?.role || 'host',
                avatarLetter:
                    userData?.full_name
                        ?.split(' ')
                        .map((n) => n[0]?.toUpperCase())
                        .slice(0, 2)
                        .join('') || 'U',
                avatarUrl: userProfile?.avatar_url || '',
            });

            setLoading(false);
        };
        fetchData();
    }, [user]);


    const hostMenuItems = [
        {
            icon: Repeat,
            label: 'Switch to guest',
            onClick: async () => {
                await switchMode();
                setOpen(false);
            },
        },
        {
            icon: BarChart2,
            label: 'Earnings Insights',
            onClick: () => {
                navigate('/host/earnings');
                setOpen(false);
            },
        },
        {
            icon: Settings,
            label: 'Account Settings',
            onClick: () => {
                navigate('/host/account-settings');
                setOpen(false);
            },
        },
        {
            icon: Share2,
            label: 'Refer a User',
            onClick: () => {
                navigate('/host/refer');
                setOpen(false);
            },
        },
        {
            icon: HelpCircle,
            label: 'Help Center',
            onClick: () => {
                window.open('/help', '_blank');
                setOpen(false);
            },
        },
    ];

    const guestMenuItems = [
        {
            icon: Repeat,
            label: 'Switch to host',
            onClick: async () => {
                await switchMode();
                setOpen(false);
            },
        },
        {
            icon: Settings,
            label: 'Account Settings',
            onClick: () => {
                navigate('/guest/account-settings');
                setOpen(false);
            },
        },
        {
            icon: Share2,
            label: 'Refer a User',
            onClick: () => {
                navigate('/guest/refer');
                setOpen(false);
            },
        },
        {
            icon: HelpCircle,
            label: 'Help Center',
            onClick: () => {
                window.open('/help', '_blank');
                setOpen(false);
            },
        },
    ];

    const menuItems = user?.role === 'host' ? hostMenuItems : guestMenuItems;

    return (
        <Sheet open={open} onOpenChange={setOpen}>
            <SheetTrigger asChild>
                <motion.button
                    whileTap={{ scale: 0.9 }}
                    className="relative w-10 h-10 rounded-full bg-gray-100 dark:bg-zinc-800 flex items-center justify-center hover:bg-gray-200 dark:hover:bg-zinc-700 transition"
                >
                    <svg viewBox="0 0 100 80" width="16" height="16" fill="currentColor">
                        <rect width="100" height="8" rx="2" />
                        <rect y="30" width="100" height="8" rx="2" />
                        <rect y="60" width="100" height="8" rx="2" />
                    </svg>
                    <motion.span
                        initial={{ scale: 0, opacity: 0 }}
                        animate={{ scale: 1, opacity: 1 }}
                        transition={{ duration: 0.3, ease: 'easeIn' }}
                        className="absolute top-0 right-0 transform translate-x-3 -translate-y-3 bg-red-500 w-2.5 h-2.5 rounded-full"
                    />
                </motion.button>
            </SheetTrigger>

            <SheetContent
                side="right"
                className="bg-white dark:bg-zinc-900 rounded-l-[36px] shadow-xl border-none p-0 w-[92vw] max-w-[520px]"
            >
                <div className="flex flex-col h-screen">


                    <div
                        className="overflow-y-auto scroll-smooth scrollbar-none px-6 pb-8 pt-0 flex-1"
                        style={{ WebkitOverflowScrolling: 'touch', scrollBehavior: 'smooth' }}
                    >
                        <AnimatePresence initial={false} mode="wait">
                            {showNotifications ? (
                                <NotificationPanel
                                    onBack={() => setShowNotifications(false)}
                                    onClose={() => setOpen(false)}
                                />
                            ) : (
                                <motion.div
                                    key="main-menu"
                                    initial={{ opacity: 0, x: 50 }}
                                    animate={{ opacity: 1, x: 0 }}
                                    exit={{ opacity: 0, x: 60 }}
                                    transition={{ type: 'spring', duration: 0.6 }}
                                    className="flex flex-col"
                                >
                                    <div className="flex justify-end items-center gap-4 p-2">
                                        <button
                                            className="relative bg-gray-100 p-2 rounded-full"
                                            onClick={() => setShowNotifications(true)}
                                        >
                                            <Bell className="h-5 w-5" />
                                            <span className="absolute top-0 right-0 w-2.5 h-2.5 bg-red-500 rounded-full border-2 border-white" />
                                        </button>
                                        <button onClick={() => setOpen(false)} className="p-2 rounded-full bg-gray-100">
                                            <X className="w-5 h-5" />
                                        </button>
                                    </div>
                                    <h2 className="text-2xl font-bold mb-6">Menu</h2>

                                    <div className="bg-[#f7f7f7] dark:bg-zinc-800 rounded-2xl p-3 mb-6 text-center">
                                        {loading ? (
                                            <div className="rounded-3xl bg-white p-6 shadow-md text-center animate-pulse">
                                                <div className="w-[96px] h-[96px] mx-auto rounded-full bg-gray-200 dark:bg-zinc-700" />
                                                <div className="h-4 bg-gray-200 dark:bg-zinc-700 w-1/2 mx-auto mt-4 rounded" />
                                                <div className="h-3 bg-gray-200 dark:bg-zinc-700 w-1/3 mx-auto mt-2 rounded" />
                                            </div>
                                        ) : (<div
                                            onClick={() => {
                                                const targetRoute = user?.role === 'guest'
                                                    ? '/guest/profile/about/edit'
                                                    : '/host/profile/about/edit';

                                                navigate(targetRoute);
                                                setOpen(false);
                                            }}

                                            className="rounded-3xl bg-white p-6 shadow-md text-center cursor-pointer transition hover:shadow-lg"
                                        >
                                            <div className="w-[96px] h-[96px] mx-auto rounded-full bg-neutral-800 text-white text-[38px] font-semibold flex items-center justify-center overflow-hidden">
                                                {profile.avatarUrl ? (
                                                    <img
                                                        src={profile.avatarUrl}
                                                        alt={`${profile.fullName} avatar`}
                                                        className="w-full h-full object-cover rounded-full"
                                                        onError={(e) => {
                                                            e.currentTarget.onerror = null;
                                                            e.currentTarget.src = '';
                                                        }}
                                                    />
                                                ) : (
                                                    <span>{profile.avatarLetter}</span>
                                                )}
                                            </div>
                                            <div className="text-[22px] font-semibold mt-2">{profile.fullName}</div>
                                            <div className="text-neutral-500 text-sm">{profile.role}</div>
                                        </div>
                                        )}
                                    </div>

                                    <div className="flex flex-col gap-4">
                                        {menuItems.map((item, idx) => (
                                            <Button
                                                key={idx}
                                                variant="ghost"
                                                className="justify-start gap-3 py-3 px-3 text-[15px] font-medium text-zinc-800 dark:text-zinc-100 hover:bg-gray-100 dark:hover:bg-zinc-800 rounded-xl transition"
                                                onClick={item.onClick}
                                            >
                                                <item.icon className="w-5 h-5" />
                                                {item.label}
                                            </Button>
                                        ))}

                                        <Button
                                            variant="ghost"
                                            onClick={async () => {
                                                await supabase.auth.signOut()
                                                window.location.href = '/login' // full reload to reflect logout
                                            }}
                                            className="justify-start gap-3 py-3 px-3 text-[15px] font-medium text-red-500 hover:bg-red-50 rounded-xl transition"
                                        >
                                            <LogOut className="w-5 h-5" />
                                            Logout
                                        </Button>
                                    </div>
                                </motion.div>
                            )}
                        </AnimatePresence>
                    </div>
                </div>
            </SheetContent>
        </Sheet>
    );
}
